@@ -1,7 +1,7 @@
 use bevy::prelude::*;
 
 use bevy_ascii_terminal::{terminal::Terminal, TerminalBundle, TerminalPlugin};
-use bevy_pixel_camera::{PixelBorderPlugin, PixelCameraBundle, PixelCameraPlugin};
+use bevy_pixel_camera::{PixelCameraBundle, PixelCameraPlugin};
 
 fn spawn_terminal(mut commands: Commands) {
     let (w, h) = (20, 3);
@@ -32,10 +32,8 @@ fn main() {
     App::build()
         .add_plugins(DefaultPlugins)
         .add_plugin(TerminalPlugin)
+        .insert_resource(ClearColor(Color::BLACK))
         .add_plugin(PixelCameraPlugin)
-        .add_plugin(PixelBorderPlugin {
-            color: Color::BLACK,
-        })
         .add_startup_system(spawn_terminal.system())
         .add_system(hello_world.system())
         .run()
