@@ -1,10 +1,13 @@
 use bevy::prelude::*;
 use bevy_ascii_terminal::{terminal::Tile, Terminal, TerminalBundle, TerminalPlugin, TerminalSize};
 
-use bevy_pixel_camera::{PixelBorderPlugin, PixelCameraBundle, PixelCameraPlugin};
+use bevy_pixel_camera::{PixelCameraBundle, PixelCameraPlugin};
 use bracket_noise::prelude::{FastNoise, NoiseType};
 use bracket_random::prelude::*;
 
+// Original example from the bracket noise library
+// https://github.com/amethyst/bracket-lib/blob/master/bracket-noise/examples/value.rs
+
 struct Noise {
     pub noise: FastNoise,
     types: Vec<NoiseType>,
@@ -131,9 +134,7 @@ fn main() {
         .add_plugins(DefaultPlugins)
         .add_plugin(TerminalPlugin)
         .add_plugin(PixelCameraPlugin)
-        .add_plugin(PixelBorderPlugin {
-            color: Color::BLACK,
-        })
+        .insert_resource(ClearColor(Color::BLACK))
         .init_resource::<Noise>()
         .add_startup_system(setup.system())
         .add_system(noise.system())
